# coding: utf-8

"""
    Rapidata Asset API

    The API for the Rapidata Asset service

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from rapidata.api_client.models.i_rapid_blueprint_attach_category_rapid_blueprint import IRapidBlueprintAttachCategoryRapidBlueprint
from rapidata.api_client.models.i_rapid_blueprint_bounding_box_rapid_blueprint import IRapidBlueprintBoundingBoxRapidBlueprint
from rapidata.api_client.models.i_rapid_blueprint_compare_rapid_blueprint import IRapidBlueprintCompareRapidBlueprint
from rapidata.api_client.models.i_rapid_blueprint_free_text_rapid_blueprint import IRapidBlueprintFreeTextRapidBlueprint
from rapidata.api_client.models.i_rapid_blueprint_line_rapid_blueprint import IRapidBlueprintLineRapidBlueprint
from rapidata.api_client.models.i_rapid_blueprint_locate_rapid_blueprint import IRapidBlueprintLocateRapidBlueprint
from rapidata.api_client.models.i_rapid_blueprint_named_entity_rapid_blueprint import IRapidBlueprintNamedEntityRapidBlueprint
from rapidata.api_client.models.i_rapid_blueprint_polygon_rapid_blueprint import IRapidBlueprintPolygonRapidBlueprint
from rapidata.api_client.models.i_rapid_blueprint_scrub_rapid_blueprint import IRapidBlueprintScrubRapidBlueprint
from rapidata.api_client.models.i_rapid_blueprint_transcription_rapid_blueprint import IRapidBlueprintTranscriptionRapidBlueprint
from pydantic import StrictStr, Field
from typing import Union, List, Set, Optional, Dict
from typing_extensions import Literal, Self

IRAPIDBLUEPRINT_ONE_OF_SCHEMAS = ["IRapidBlueprintAttachCategoryRapidBlueprint", "IRapidBlueprintBoundingBoxRapidBlueprint", "IRapidBlueprintCompareRapidBlueprint", "IRapidBlueprintFreeTextRapidBlueprint", "IRapidBlueprintLineRapidBlueprint", "IRapidBlueprintLocateRapidBlueprint", "IRapidBlueprintNamedEntityRapidBlueprint", "IRapidBlueprintPolygonRapidBlueprint", "IRapidBlueprintScrubRapidBlueprint", "IRapidBlueprintTranscriptionRapidBlueprint"]

class IRapidBlueprint(BaseModel):
    """
    IRapidBlueprint
    """
    # data type: IRapidBlueprintTranscriptionRapidBlueprint
    oneof_schema_1_validator: Optional[IRapidBlueprintTranscriptionRapidBlueprint] = None
    # data type: IRapidBlueprintScrubRapidBlueprint
    oneof_schema_2_validator: Optional[IRapidBlueprintScrubRapidBlueprint] = None
    # data type: IRapidBlueprintPolygonRapidBlueprint
    oneof_schema_3_validator: Optional[IRapidBlueprintPolygonRapidBlueprint] = None
    # data type: IRapidBlueprintNamedEntityRapidBlueprint
    oneof_schema_4_validator: Optional[IRapidBlueprintNamedEntityRapidBlueprint] = None
    # data type: IRapidBlueprintLocateRapidBlueprint
    oneof_schema_5_validator: Optional[IRapidBlueprintLocateRapidBlueprint] = None
    # data type: IRapidBlueprintLineRapidBlueprint
    oneof_schema_6_validator: Optional[IRapidBlueprintLineRapidBlueprint] = None
    # data type: IRapidBlueprintFreeTextRapidBlueprint
    oneof_schema_7_validator: Optional[IRapidBlueprintFreeTextRapidBlueprint] = None
    # data type: IRapidBlueprintCompareRapidBlueprint
    oneof_schema_8_validator: Optional[IRapidBlueprintCompareRapidBlueprint] = None
    # data type: IRapidBlueprintAttachCategoryRapidBlueprint
    oneof_schema_9_validator: Optional[IRapidBlueprintAttachCategoryRapidBlueprint] = None
    # data type: IRapidBlueprintBoundingBoxRapidBlueprint
    oneof_schema_10_validator: Optional[IRapidBlueprintBoundingBoxRapidBlueprint] = None
    actual_instance: Optional[Union[IRapidBlueprintAttachCategoryRapidBlueprint, IRapidBlueprintBoundingBoxRapidBlueprint, IRapidBlueprintCompareRapidBlueprint, IRapidBlueprintFreeTextRapidBlueprint, IRapidBlueprintLineRapidBlueprint, IRapidBlueprintLocateRapidBlueprint, IRapidBlueprintNamedEntityRapidBlueprint, IRapidBlueprintPolygonRapidBlueprint, IRapidBlueprintScrubRapidBlueprint, IRapidBlueprintTranscriptionRapidBlueprint]] = None
    one_of_schemas: Set[str] = { "IRapidBlueprintAttachCategoryRapidBlueprint", "IRapidBlueprintBoundingBoxRapidBlueprint", "IRapidBlueprintCompareRapidBlueprint", "IRapidBlueprintFreeTextRapidBlueprint", "IRapidBlueprintLineRapidBlueprint", "IRapidBlueprintLocateRapidBlueprint", "IRapidBlueprintNamedEntityRapidBlueprint", "IRapidBlueprintPolygonRapidBlueprint", "IRapidBlueprintScrubRapidBlueprint", "IRapidBlueprintTranscriptionRapidBlueprint" }

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    discriminator_value_class_map: Dict[str, str] = {
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = IRapidBlueprint.model_construct()
        error_messages = []
        match = 0
        # validate data type: IRapidBlueprintTranscriptionRapidBlueprint
        if not isinstance(v, IRapidBlueprintTranscriptionRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintTranscriptionRapidBlueprint`")
        else:
            match += 1
        # validate data type: IRapidBlueprintScrubRapidBlueprint
        if not isinstance(v, IRapidBlueprintScrubRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintScrubRapidBlueprint`")
        else:
            match += 1
        # validate data type: IRapidBlueprintPolygonRapidBlueprint
        if not isinstance(v, IRapidBlueprintPolygonRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintPolygonRapidBlueprint`")
        else:
            match += 1
        # validate data type: IRapidBlueprintNamedEntityRapidBlueprint
        if not isinstance(v, IRapidBlueprintNamedEntityRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintNamedEntityRapidBlueprint`")
        else:
            match += 1
        # validate data type: IRapidBlueprintLocateRapidBlueprint
        if not isinstance(v, IRapidBlueprintLocateRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintLocateRapidBlueprint`")
        else:
            match += 1
        # validate data type: IRapidBlueprintLineRapidBlueprint
        if not isinstance(v, IRapidBlueprintLineRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintLineRapidBlueprint`")
        else:
            match += 1
        # validate data type: IRapidBlueprintFreeTextRapidBlueprint
        if not isinstance(v, IRapidBlueprintFreeTextRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintFreeTextRapidBlueprint`")
        else:
            match += 1
        # validate data type: IRapidBlueprintCompareRapidBlueprint
        if not isinstance(v, IRapidBlueprintCompareRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintCompareRapidBlueprint`")
        else:
            match += 1
        # validate data type: IRapidBlueprintAttachCategoryRapidBlueprint
        if not isinstance(v, IRapidBlueprintAttachCategoryRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintAttachCategoryRapidBlueprint`")
        else:
            match += 1
        # validate data type: IRapidBlueprintBoundingBoxRapidBlueprint
        if not isinstance(v, IRapidBlueprintBoundingBoxRapidBlueprint):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IRapidBlueprintBoundingBoxRapidBlueprint`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in IRapidBlueprint with oneOf schemas: IRapidBlueprintAttachCategoryRapidBlueprint, IRapidBlueprintBoundingBoxRapidBlueprint, IRapidBlueprintCompareRapidBlueprint, IRapidBlueprintFreeTextRapidBlueprint, IRapidBlueprintLineRapidBlueprint, IRapidBlueprintLocateRapidBlueprint, IRapidBlueprintNamedEntityRapidBlueprint, IRapidBlueprintPolygonRapidBlueprint, IRapidBlueprintScrubRapidBlueprint, IRapidBlueprintTranscriptionRapidBlueprint. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in IRapidBlueprint with oneOf schemas: IRapidBlueprintAttachCategoryRapidBlueprint, IRapidBlueprintBoundingBoxRapidBlueprint, IRapidBlueprintCompareRapidBlueprint, IRapidBlueprintFreeTextRapidBlueprint, IRapidBlueprintLineRapidBlueprint, IRapidBlueprintLocateRapidBlueprint, IRapidBlueprintNamedEntityRapidBlueprint, IRapidBlueprintPolygonRapidBlueprint, IRapidBlueprintScrubRapidBlueprint, IRapidBlueprintTranscriptionRapidBlueprint. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into IRapidBlueprintTranscriptionRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintTranscriptionRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into IRapidBlueprintScrubRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintScrubRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into IRapidBlueprintPolygonRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintPolygonRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into IRapidBlueprintNamedEntityRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintNamedEntityRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into IRapidBlueprintLocateRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintLocateRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into IRapidBlueprintLineRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintLineRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into IRapidBlueprintFreeTextRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintFreeTextRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into IRapidBlueprintCompareRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintCompareRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into IRapidBlueprintAttachCategoryRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintAttachCategoryRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into IRapidBlueprintBoundingBoxRapidBlueprint
        try:
            instance.actual_instance = IRapidBlueprintBoundingBoxRapidBlueprint.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into IRapidBlueprint with oneOf schemas: IRapidBlueprintAttachCategoryRapidBlueprint, IRapidBlueprintBoundingBoxRapidBlueprint, IRapidBlueprintCompareRapidBlueprint, IRapidBlueprintFreeTextRapidBlueprint, IRapidBlueprintLineRapidBlueprint, IRapidBlueprintLocateRapidBlueprint, IRapidBlueprintNamedEntityRapidBlueprint, IRapidBlueprintPolygonRapidBlueprint, IRapidBlueprintScrubRapidBlueprint, IRapidBlueprintTranscriptionRapidBlueprint. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into IRapidBlueprint with oneOf schemas: IRapidBlueprintAttachCategoryRapidBlueprint, IRapidBlueprintBoundingBoxRapidBlueprint, IRapidBlueprintCompareRapidBlueprint, IRapidBlueprintFreeTextRapidBlueprint, IRapidBlueprintLineRapidBlueprint, IRapidBlueprintLocateRapidBlueprint, IRapidBlueprintNamedEntityRapidBlueprint, IRapidBlueprintPolygonRapidBlueprint, IRapidBlueprintScrubRapidBlueprint, IRapidBlueprintTranscriptionRapidBlueprint. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], IRapidBlueprintAttachCategoryRapidBlueprint, IRapidBlueprintBoundingBoxRapidBlueprint, IRapidBlueprintCompareRapidBlueprint, IRapidBlueprintFreeTextRapidBlueprint, IRapidBlueprintLineRapidBlueprint, IRapidBlueprintLocateRapidBlueprint, IRapidBlueprintNamedEntityRapidBlueprint, IRapidBlueprintPolygonRapidBlueprint, IRapidBlueprintScrubRapidBlueprint, IRapidBlueprintTranscriptionRapidBlueprint]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())


