# coding: utf-8

"""
    Rapidata Asset API

    The API for the Rapidata Asset service

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from rapidata.api_client.models.aggregator_type import AggregatorType
from rapidata.api_client.models.feature_flag_model import FeatureFlagModel
from rapidata.api_client.models.i_order_workflow_model import IOrderWorkflowModel
from rapidata.api_client.models.i_referee_model import IRefereeModel
from rapidata.api_client.models.i_selection import ISelection
from rapidata.api_client.models.i_user_filter_model import IUserFilterModel
from rapidata.api_client.models.retrieval_mode import RetrievalMode
from rapidata.api_client.models.sticky_state import StickyState
from typing import Optional, Set
from typing_extensions import Self

class CreateOrderModel(BaseModel):
    """
    CreateOrderModel
    """ # noqa: E501
    order_name: StrictStr = Field(alias="orderName")
    workflow: IOrderWorkflowModel
    referee: IRefereeModel
    aggregator: Optional[AggregatorType] = None
    feature_flags: Optional[List[FeatureFlagModel]] = Field(default=None, alias="featureFlags")
    priority: Optional[StrictInt] = None
    sticky_state: Optional[StickyState] = Field(default=None, alias="stickyState")
    user_score_dimensions: Optional[List[StrictStr]] = Field(default=None, alias="userScoreDimensions")
    demographic_keys: Optional[List[StrictStr]] = Field(default=None, alias="demographicKeys")
    user_filters: Optional[List[IUserFilterModel]] = Field(default=None, alias="userFilters")
    validation_set_id: Optional[StrictStr] = Field(default=None, alias="validationSetId")
    selections: Optional[List[ISelection]] = None
    retrieval_mode: Optional[RetrievalMode] = Field(default=None, alias="retrievalMode")
    max_iterations: Optional[StrictInt] = Field(default=None, alias="maxIterations")
    __properties: ClassVar[List[str]] = ["orderName", "workflow", "referee", "aggregator", "featureFlags", "priority", "stickyState", "userScoreDimensions", "demographicKeys", "userFilters", "validationSetId", "selections", "retrievalMode", "maxIterations"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateOrderModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of workflow
        if self.workflow:
            _dict['workflow'] = self.workflow.to_dict()
        # override the default output from pydantic by calling `to_dict()` of referee
        if self.referee:
            _dict['referee'] = self.referee.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in feature_flags (list)
        _items = []
        if self.feature_flags:
            for _item_feature_flags in self.feature_flags:
                if _item_feature_flags:
                    _items.append(_item_feature_flags.to_dict())
            _dict['featureFlags'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in user_filters (list)
        _items = []
        if self.user_filters:
            for _item_user_filters in self.user_filters:
                if _item_user_filters:
                    _items.append(_item_user_filters.to_dict())
            _dict['userFilters'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in selections (list)
        _items = []
        if self.selections:
            for _item_selections in self.selections:
                if _item_selections:
                    _items.append(_item_selections.to_dict())
            _dict['selections'] = _items
        # set to None if aggregator (nullable) is None
        # and model_fields_set contains the field
        if self.aggregator is None and "aggregator" in self.model_fields_set:
            _dict['aggregator'] = None

        # set to None if sticky_state (nullable) is None
        # and model_fields_set contains the field
        if self.sticky_state is None and "sticky_state" in self.model_fields_set:
            _dict['stickyState'] = None

        # set to None if validation_set_id (nullable) is None
        # and model_fields_set contains the field
        if self.validation_set_id is None and "validation_set_id" in self.model_fields_set:
            _dict['validationSetId'] = None

        # set to None if retrieval_mode (nullable) is None
        # and model_fields_set contains the field
        if self.retrieval_mode is None and "retrieval_mode" in self.model_fields_set:
            _dict['retrievalMode'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateOrderModel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "orderName": obj.get("orderName"),
            "workflow": IOrderWorkflowModel.from_dict(obj["workflow"]) if obj.get("workflow") is not None else None,
            "referee": IRefereeModel.from_dict(obj["referee"]) if obj.get("referee") is not None else None,
            "aggregator": obj.get("aggregator"),
            "featureFlags": [FeatureFlagModel.from_dict(_item) for _item in obj["featureFlags"]] if obj.get("featureFlags") is not None else None,
            "priority": obj.get("priority"),
            "stickyState": obj.get("stickyState"),
            "userScoreDimensions": obj.get("userScoreDimensions"),
            "demographicKeys": obj.get("demographicKeys"),
            "userFilters": [IUserFilterModel.from_dict(_item) for _item in obj["userFilters"]] if obj.get("userFilters") is not None else None,
            "validationSetId": obj.get("validationSetId"),
            "selections": [ISelection.from_dict(_item) for _item in obj["selections"]] if obj.get("selections") is not None else None,
            "retrievalMode": obj.get("retrievalMode"),
            "maxIterations": obj.get("maxIterations")
        })
        return _obj


