# coding: utf-8

"""
    Rapidata Asset API

    The API for the Rapidata Asset service

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictBytes, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Tuple, Union
from rapidata.api_client.models.entity_tag_header_value import EntityTagHeaderValue
from typing import Optional, Set
from typing_extensions import Self

class FileStreamResult(BaseModel):
    """
    FileStreamResult
    """ # noqa: E501
    file_stream: Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]] = Field(default=None, alias="fileStream")
    content_type: Optional[StrictStr] = Field(default=None, alias="contentType")
    file_download_name: Optional[StrictStr] = Field(default=None, alias="fileDownloadName")
    last_modified: Optional[datetime] = Field(default=None, alias="lastModified")
    entity_tag: Optional[EntityTagHeaderValue] = Field(default=None, alias="entityTag")
    enable_range_processing: Optional[StrictBool] = Field(default=None, alias="enableRangeProcessing")
    __properties: ClassVar[List[str]] = ["fileStream", "contentType", "fileDownloadName", "lastModified", "entityTag", "enableRangeProcessing"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FileStreamResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of entity_tag
        if self.entity_tag:
            _dict['entityTag'] = self.entity_tag.to_dict()
        # set to None if content_type (nullable) is None
        # and model_fields_set contains the field
        if self.content_type is None and "content_type" in self.model_fields_set:
            _dict['contentType'] = None

        # set to None if file_download_name (nullable) is None
        # and model_fields_set contains the field
        if self.file_download_name is None and "file_download_name" in self.model_fields_set:
            _dict['fileDownloadName'] = None

        # set to None if last_modified (nullable) is None
        # and model_fields_set contains the field
        if self.last_modified is None and "last_modified" in self.model_fields_set:
            _dict['lastModified'] = None

        # set to None if entity_tag (nullable) is None
        # and model_fields_set contains the field
        if self.entity_tag is None and "entity_tag" in self.model_fields_set:
            _dict['entityTag'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FileStreamResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "fileStream": obj.get("fileStream"),
            "contentType": obj.get("contentType"),
            "fileDownloadName": obj.get("fileDownloadName"),
            "lastModified": obj.get("lastModified"),
            "entityTag": EntityTagHeaderValue.from_dict(obj["entityTag"]) if obj.get("entityTag") is not None else None,
            "enableRangeProcessing": obj.get("enableRangeProcessing")
        })
        return _obj


